art — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

# art

Manages icons and artworks

class `camelot.view.art.` `ColorScheme`

  The default color scheme for camelot, based on the Tango icon set see http://tango.freedesktop.org/Generic_Icon_Theme_Guidelines

  `NOTIFICATION` = <PyQt4.QtGui.QColor object at 0x9d19c6c>

    for consistency with QT: Qt::white 3 White (#ffffff) Qt::black 2 Black (#000000) Qt::red 7 Red (#ff0000) Qt::darkRed 13 Dark red (#800000) Qt::green 8 Green (#00ff00) Qt::darkGreen 14 Dark green (#008000) Qt::blue 9 Blue (#0000ff) Qt::darkBlue 15 Dark blue () Qt::cyan 10 Cyan (#00ffff) Qt::darkCyan 16 Dark cyan (#008080) Qt::magenta 11 Magenta (#ff00ff) Qt::darkMagenta 17 Dark magenta (#800080) Qt::yellow 12 Yellow (#ffff00) Qt::darkYellow 18 Dark yellow (#808000) Qt::gray 5 Gray (#a0a0a4) Qt::darkGray 4 Dark gray (#808080) Qt::lightGray 6 Light gray (#c0c0c0) Qt::transparent 19 a transparent black value (i.e., QColor(0, 0, 0, 0)) Qt::color0 0 0 pixel value (for bitmaps) Qt::color1 1 1 pixel value (for bitmaps)

class `camelot.view.art.` `Icon`(path, module=None)

  Manages paths to the icons images

  `getQIcon`(*args, **kwargs)

    QPixmaps can only be used in the gui thread

class `camelot.view.art.` `Pixmap`(path, module=None)

  Load pixmaps from the camelot art library

  `fullpath`()

    Obsolete : avoid this method, since it will copy the resource file from its package and copy it to a temp folder if the resource is packaged.

  `getQPixmap`(*args, **kwargs)

    QPixmaps can only be used in the gui thread

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »

Comments
blog comments powered by Disqus